# Jupyter Community Call 1/31

**Date:** January 31, 2023 at 7am Pacific (in your [timezone](https://arewemeetingyet.com/Los%20Angeles/2023-01-31/7:00/Jupyter%20Community%20Call))

[**Discourse**](https://discourse.jupyter.org/t/jupyter-community-calls/668)
[**Youtube**](https://youtu.be/LjgctsAIubQ)

**Please note:**
- Community calls are recorded and posted to this [playlist](https://www.youtube.com/playlist?list=PLUrHeD2K9Cmkoamm4NjLmvXC4Y6E1o8SP)
- These notes will be recorded and posted [here](https://jupyter.readthedocs.io/en/latest/community/community-call-notes/index.html)
- Everyone present is held to the [Jupyter Code of Conduct](https://jupyter.org/conduct)

## Purpose

Think of it as a monthly, virtual JupyterCon. It’s a place to announce and share fun things happening in the Jupyter community.

For more discussion on the format of these calls, see the thread [here](https://discourse.jupyter.org/t/reviving-the-all-jupyter-team-meetings/423).

## Short reports, celebrations, shout-outs

This is a place to make short announcements (without a need for discussion). 

* **Isabela** We've officially hit two years of consecutive Jupyter community calls! Thank you all for supporting our community.
* **Nick** Recent [release of traitlets](https://blog.jupyter.org/announcing-a-new-jupyter-governance-model-and-our-first-executive-council-39b3989dc064) supports tab completion
* **Gayle** [Blog post](https://blog.jupyter.org/announcing-a-new-jupyter-governance-model-and-our-first-executive-council-39b3989dc064) about Jupyter governance launch

## Agenda Items

Add agenda items here **before** the meeting. We will reorganize the agenda so that it fits in the 60m meeting slot.

* **Stephen Macke**: [IPyflow](https://github.com/ipyflow/ipyflow): a dataflow-aware Python kernel for JupyterLab
* **Nick Bollweg**: [jyg](https://github.com/deathbeds/jyg): run JupyterLab commands from the CLI... or other browser windows
* **Gayle**: [Jupytercon](https://www.jupytercon.com/)! How would you promote the event? Reach out at gayle@numfocus.org
* **Kafonek**: Are any Jupyter-collaborative meetings (Y-py, etc) still going on? Have tried to connect to those communities and had trouble. Also would like to push for pypi to host wasm wheels.

## Other Links Shared

This is a space to store links shared during community call discussions related to or separate from the agenda items.

* [deathbeds/jupyterlab-starters](https://github.com/deathbeds/jupyterlab-starters)
* [JupyterLab example for adding items to the launcher](https://github.com/jupyterlab/extension-examples/tree/master/launcher) 
* [jupyter_app_launcher](https://github.com/trungleduc/jupyter_app_launcher)
* [jupyterlab_commands](https://github.com/timkpaine/jupyterlab_commands)
* [ipylab](https://github.com/jtpio/ipylab)

## Attendees 

|   Name   |           Institution     | GitHub Handle|
|----------|---------------------------|--------------|
| nick bollweg | deathbeds | @bollwyvl  |
| stephen macke | meta | [@smacke](https://github.com/smacke) |
| matt kafonek | noteable | [@kafonek](https://github.com/kafonek) |
| Frederic Collonval | QuantStack | @fcollonval  |
| Gayle Ollington     | NumFOCUS | @gollington  |
| Wayne Decatur | Upstate Medical Univ. | @fomightez |
| Carlos Brandt | Constructor Univ. | @chbrandt |
| tonyfast | deathbeds | @tonyfast |
| A. T. Darian | QuantStack  | @afshin |
| Isabela Presedo-Floyd | Quansight Labs | @isabela-pf |

Plus 3 more